@@ -2,6 +2,6 @@ from .sortable import SingleSortPlugin
 from .output import DjangoTemplatePlugin
 from .paginator import PaginatorPlugin
 from .quicksearch import QuickSearchORM
-from .actions import PostAction
+from .actions import ActionsState, PostAction
 from .sortable import SingleSortPlugin
 from .filters import CategoryFilter
